#include <fstream>
#include <vector>
#include <list>
#include <assert.h>

std::vector<std::vector<int> > winMatrix;
std::vector<int> newParticipants0, newParticipants1, newParticipants2;
std::vector<std::list<int> > subContests;
int n, t;

void makeNewStage(const std::vector<std::pair<int, int> >& matches, std::vector<int>& result)
{
  result.resize(matches.size());
  for (int i = 0; i < matches.size(); ++i)
    result[i] = winMatrix[matches[i].first][matches[i].second] ? matches[i].first : matches[i].second;
}

double stageCost (const std::vector<int>& participants)
{
  int maxCost = -1E5;
  int maxCostCnt = 0;

  std::vector<int> alive(n, 0);
  for (int i = 0; i < participants.size(); ++i)
    alive[participants[i]] = 1;

  if (!alive[t]) return 1E5;
  for (int i = 0; i < participants.size(); ++i)
  {
    if (t != participants[i])
    {
      int cost = 0;
      for (int j = 0; j < n; ++j)
        if (alive[j])
          cost += winMatrix[participants[i]][j] - winMatrix[t][j];

      if (cost > maxCost)
      {
        maxCost = cost;
        maxCostCnt = 1;
      }
      else if (cost == maxCost) 
        maxCostCnt++;
    }
  }

  return maxCost + (maxCostCnt - 1) * 0.00001;
}

int main (int argc, char** argv)
{
  std::fstream input("input.txt", std::ios_base::in);
  std::fstream output("output.txt", std::ios_base::out);

  input >> n >> t;
  winMatrix.resize(n);
  subContests.resize(n);
  for (int i = 0; i < n; ++i)
  {
    winMatrix[i].resize(n);
    for (int j = 0; j < n; ++j)
      input >> winMatrix[i][j];
  }

  std::vector<int> participants(n);
  for (int i = 0; i < n; i++)
  {
    participants[i] = i;
    subContests[i].push_back(i);
  }

  while(participants.size() > 1)
  {
//    assert(stageCost(participants) <= 0);

    assert(participants.size() % 2 == 0);
    std::vector<std::pair<int, int> > matches(participants.size() / 2);
    for (int i = 0; i < matches.size(); ++i)
      matches[i] = std::make_pair(participants[2 * i], participants[2 * i + 1]);
    
    bool upgradeMade;
    do
    {
      upgradeMade = false;
      for (int i = 0; i < matches.size(); ++i)
        for (int j = i + 1; j < matches.size(); ++j)
        {
          makeNewStage(matches, newParticipants0);
          double cost0 = stageCost(newParticipants0);

          std::vector<std::pair<int, int> > matches1 = matches;
          std::swap(matches1[i].first, matches1[j].first);
          makeNewStage(matches1, newParticipants1);
          double cost1 = stageCost(newParticipants1);
          
          std::vector<std::pair<int, int> > matches2 = matches;
          std::swap(matches2[i].first, matches2[j].second);
          makeNewStage(matches2, newParticipants2);
          double cost2 = stageCost(newParticipants2);

          if (cost1 < cost0)
          {
            cost0 = cost1;
            upgradeMade = true;
            matches = matches1;
          }
          
          if (cost2 < cost0)
          {
            cost0 = cost2;
            upgradeMade = true;
            matches = matches2;
          }
        }
    } while (upgradeMade);

    for (int i = 0; i < matches.size(); ++i)
    {
      if (!winMatrix[matches[i].first][matches[i].second]) std::swap(matches[i].first, matches[i].second);
      subContests[matches[i].first].splice(subContests[matches[i].first].end(), subContests[matches[i].second]);
    }

    makeNewStage(matches, participants);
  }

  assert(participants[0] == t);

  for (std::list<int>::const_iterator it = subContests[t].begin(); it != subContests[t].end(); it++)
    output << *it << " ";

  return 0;
}